@@ -1,14 +1,14 @@
 package Mojolicious::Plugin::Log::Access;
-use Mojo::Base 'Mojolicious::Plugin';
+use Mojolicious::Plugin -base;
 
-our $VERSION = 0.023;
+our $VERSION = 0.031;
 
 sub register {
   my ($self, $app) = @_;
   $app->hook(after_dispatch => sub {
     my $c = shift;
-    $app->log->info(sprintf '%s "%s" %s',
-        $c->tx->remote_address, $c->req->url->to_abs->path, $c->res->code);
+    $app->log->info(sprintf '%s "%s" %s', $c->tx->remote_address,
+        $c->req->url->to_abs->path_query, $c->res->code);
   });
 }
 
